==> datadog_api_client-2.29.0.tar.gz: datadog_api_client-2.29.0/src/datadog_api_client/v2/model/upsert_catalog_entity_response_included_item.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelComposed,
    cached_property,
)


class UpsertCatalogEntityResponseIncludedItem(ModelComposed):
    def __init__(self, **kwargs):
        """
        Upsert entity response included item.

        :param attributes: Included schema.
        :type attributes: EntityResponseIncludedSchemaAttributes, optional

        :param id: Entity id.
        :type id: str, optional

        :param type: Schema type.
        :type type: str, optional
        """
        super().__init__(kwargs)

    @cached_property
    def _composed_schemas(_):
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        from datadog_api_client.v2.model.entity_response_included_schema import EntityResponseIncludedSchema

        return {
            "oneOf": [
                EntityResponseIncludedSchema,
            ],
        }

==> datadog_api_client-2.39.0.tar.gz: datadog_api_client-2.39.0/src/datadog_api_client/v2/model/upsert_catalog_entity_response_included_item.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelComposed,
    cached_property,
)


class UpsertCatalogEntityResponseIncludedItem(ModelComposed):
    def __init__(self, **kwargs):
        """
        Upsert entity response included item.

        :param attributes: Included schema.
        :type attributes: EntityResponseIncludedSchemaAttributes, optional

        :param id: Entity ID.
        :type id: str, optional

        :param type: Schema type.
        :type type: EntityResponseIncludedSchemaType, optional
        """
        super().__init__(kwargs)

    @cached_property
    def _composed_schemas(_):
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        from datadog_api_client.v2.model.entity_response_included_schema import EntityResponseIncludedSchema

        return {
            "oneOf": [
                EntityResponseIncludedSchema,
            ],
        }
